Skip to contents

The CDC stores their multiple cause of death files on an FTP in fixed-width format. However, the naming convention changes slightly from year to year. This dictionary just contains the file name and the year as 12/24/2017.

Usage

cdc_dict

Format

A dictionary

key

chr, year of file

value

chr, URL of file