Download the multiple cause of death data as an ASCII file from the CDC
Source:R/download_mcod_fwf.R
dot-download_mcod_fwf.RdThe CDC hosts publicly available multiple cause of death data as a fixed-
width text file. This function downloads that file as a zip. Note that the
CDC server can be slow–downloading from NBER via the download_mcod_dta() or
download_mcod_csv() functions is strongly suggested. Coverage in
cdc_dict runs through the most recent public-use year (currently 2024).