Skip to contents

NBER hosts publicly available multiple cause of death data in several formats (see source). This function downloads the specified year to the specified folder in the DTA (Stata) format.

Usage

download_mcod_dta(year, download_dir = "./raw_data")

http://www.nber.org/data/vital-statistics-mortality-data-multiple-cause-of-death.html

Arguments

year

year to download (as integer)

download_dir

file path to save downloaded data

Value

none

Examples

if (FALSE) { # \dontrun{
download_mcod_dta(2019, download_dir = tempdir())
} # }