Dataframe of annual population counts by age and race, 1979-2020
Source:R/data-pop_est.R
pop_est.RdA data set containing annual population counts by age (5-year bins, 18 groups), sex, and race. All data are from the US Census Bureau Population Estimates Program.