Create a categorical age column from a converted ager27 column
Source:R/categorize_age_5u1.R
categorize_age_5u1.RdSimply makes more meaningful labels on the age column. Assumes that the age column was created from the convert_ager27() function. Allows for using tidyr::complete() even when some age/year/race combinations have no observations.