A dictionary of year:URL key:value pairs for the CDC FTP MCOD files
Source:R/data-cdc_dict.R
cdc_dict.RdThe CDC stores their multiple cause of death files on an FTP in fixed-width format. However, the naming convention changes slightly from year to year. This dictionary just contains the file name and the year as 12/24/2017.