Download the multiple cause of death data as a CSV file
Source:R/download_mcod_csv.R
download_mcod_csv.RdNBER hosts publicly available multiple cause of death data in several formats (see source). This function downloads the specified year to the specified folder in the CSV format.
Examples
if (FALSE) { # \dontrun{
download_mcod_csv(2019, download_dir = tempdir())
} # }