Download the multiple cause of death data as a DTA file
Source:R/download_mcod_dta.R
download_mcod_dta.RdNBER hosts publicly available multiple cause of death data in several formats (see source). This function downloads the specified year to the specified folder in the DTA (Stata) format.
Examples
if (FALSE) { # \dontrun{
download_mcod_dta(2019, download_dir = tempdir())
} # }