Download NCHS Natality (Live Births) Data from the CDC FTP (ASCII)
Source:R/download_natality_ascii.R
download_natality_ascii.RdFair warning: These files are very large when uncompressed. They range between 3 and 5 GB uncompressed with a compression ratio of around 90 Also, it appears the CDC rate limits downloads so I do not export this function. To use it, you'll need to use the triple colon: `narcan:::download_natality_ascii()`.